@@ -1,19 +1,19 @@
-require "spec_helper"
+require "rails_helper"
 
 <% module_namespacing do -%>
-describe <%= class_name %> do
+RSpec.describe <%= class_name %>, <%= type_metatag(:mailer) %> do
 <% for action in actions -%>
   describe "<%= action %>" do
     let(:mail) { <%= class_name %>.<%= action %> }
 
     it "renders the headers" do
-      mail.subject.should eq(<%= action.to_s.humanize.inspect %>)
-      mail.to.should eq(["to@example.org"])
-      mail.from.should eq(["from@example.com"])
+      expect(mail.subject).to eq(<%= action.to_s.humanize.inspect %>)
+      expect(mail.to).to eq(["to@example.org"])
+      expect(mail.from).to eq(["from@example.com"])
     end
 
     it "renders the body" do
-      mail.body.encoded.should match("Hi")
+      expect(mail.body.encoded).to match("Hi")
     end
   end
 
