@@ -1,7 +1,7 @@
-require 'spec_helper'
+require 'rails_helper'
 
 <% module_namespacing do -%>
-describe <%= class_name %>Observer do
+RSpec.describe <%= class_name %>Observer, <%= type_metatag(:observer) %> do
   pending "add some examples to (or delete) #{__FILE__}"
 end
 <% end -%>
