@@ -1,18 +1,16 @@
 require 'rspec/core'
-
-RSpec::configure do |c|
-  c.backtrace_exclusion_patterns << /vendor\//
-  c.backtrace_exclusion_patterns << /lib\/rspec\/rails/
-end
-
 require 'rails/version'
-require 'rspec/rails/extensions'
-require 'rspec/rails/view_rendering'
+
+# Load any of our adapters and extensions early in the process
 require 'rspec/rails/adapters'
+require 'rspec/rails/extensions'
+
+# Load the rspec-rails parts
+require 'rspec/rails/view_rendering'
 require 'rspec/rails/matchers'
 require 'rspec/rails/fixture_support'
-require 'rspec/rails/mocks'
-require 'rspec/rails/module_inclusion'
 require 'rspec/rails/example'
 require 'rspec/rails/vendor/capybara'
-require 'rspec/rails/vendor/webrat'
+require 'rspec/rails/configuration'
+require 'rspec/rails/active_record'
+require 'rspec/rails/feature_check'
