@@ -3,7 +3,7 @@ require "spec_helper"
 describe RSpec::Rails::AssertionDelegator do
   it "provides a module that delegates assertion methods to an isolated class" do
     klass = Class.new {
-      include RSpec::Rails::AssertionDelegator.new(Test::Unit::Assertions)
+      include RSpec::Rails::AssertionDelegator.new(RSpec::Rails::Assertions)
     }
 
     expect(klass.new).to respond_to(:assert)
