@@ -2,15 +2,8 @@ require "spec_helper"
 
 module RSpec::Rails
   describe RoutingExampleGroup do
-    it { should be_included_in_files_in('./spec/routing/') }
-    it { should be_included_in_files_in('.\\spec\\routing\\') }
-
-    it "adds :type => :routing to the metadata" do
-      group = RSpec::Core::ExampleGroup.describe do
-        include RoutingExampleGroup
-      end
-      group.metadata[:type].should eq(:routing)
-    end
+    it_behaves_like "an rspec-rails example group mixin", :routing,
+      './spec/routing/', '.\\spec\\routing\\'
 
     describe "named routes" do
       it "delegates them to the route_set" do
@@ -23,9 +16,9 @@ module RSpec::Rails
         # Yes, this is quite invasive
         url_helpers = double('url_helpers', :foo_path => "foo")
         routes = double('routes', :url_helpers => url_helpers)
-        example.stub(:routes => routes)
+        allow(example).to receive_messages(:routes => routes)
 
-        example.foo_path.should == "foo"
+        expect(example.foo_path).to eq("foo")
       end
     end
   end
