@@ -2,15 +2,8 @@ require "spec_helper"
 
 module RSpec::Rails
   describe ViewExampleGroup do
-    it { should be_included_in_files_in('./spec/views/') }
-    it { should be_included_in_files_in('.\\spec\\views\\') }
-
-    it "adds :type => :view to the metadata" do
-      group = RSpec::Core::ExampleGroup.describe do
-        include ViewExampleGroup
-      end
-      group.metadata[:type].should eq(:view)
-    end
+    it_behaves_like "an rspec-rails example group mixin", :view,
+      './spec/views/', '.\\spec\\views\\'
 
     describe 'automatic inclusion of helpers' do
       module ::ThingsHelper; end
@@ -18,27 +11,36 @@ module RSpec::Rails
 
       it 'includes the helper with the same name' do
         group = RSpec::Core::ExampleGroup.describe 'things/show.html.erb'
-        group.should_receive(:helper).with(ThingsHelper)
-        group.class_eval do
+        expect(group).to receive(:helper).with(ThingsHelper)
+        group.class_exec do
           include ViewExampleGroup
         end
       end
 
       it 'includes the namespaced helper with the same name' do
         group = RSpec::Core::ExampleGroup.describe 'namespaced/things/show.html.erb'
-        group.should_receive(:helper).with(Namespaced::ThingsHelper)
-        group.class_eval do
+        expect(group).to receive(:helper).with(Namespaced::ThingsHelper)
+        group.class_exec do
           include ViewExampleGroup
         end
       end
 
       it 'operates normally when no helper with the same name exists' do
         raise 'unexpected constant found' if Object.const_defined?('ClocksHelper')
-        lambda {
+        expect {
           RSpec::Core::ExampleGroup.describe 'clocks/show.html.erb' do
             include ViewExampleGroup
           end
-        }.should_not raise_error
+        }.not_to raise_error
+      end
+
+      it 'operates normally when the view has no path and there is a Helper class defined' do
+        class ::Helper; end
+        expect {
+          RSpec::Core::ExampleGroup.describe 'show.html.erb' do
+            include ViewExampleGroup
+          end
+        }.not_to raise_error
       end
 
       context 'application helper exists' do
@@ -57,8 +59,8 @@ module RSpec::Rails
 
         it 'includes the application helper' do
           group = RSpec::Core::Example.describe 'bars/new.html.erb'
-          group.should_receive(:helper).with(ApplicationHelper)
-          group.class_eval do
+          expect(group).to receive(:helper).with(ApplicationHelper)
+          group.class_exec do
             include ViewExampleGroup
           end
         end
@@ -73,17 +75,17 @@ module RSpec::Rails
         end
 
         after do
-          if @application_helper
+          if defined?(@application_helper)
             ApplicationHelper = @application_helper
           end
         end
 
         it 'operates normally' do
-          lambda {
+          expect {
             RSpec::Core::ExampleGroup.describe 'foos/edit.html.erb' do
               include ViewExampleGroup
             end
-          }.should_not raise_error
+          }.not_to raise_error
         end
       end
     end
@@ -91,7 +93,7 @@ module RSpec::Rails
     describe "#render" do
       let(:view_spec) do
         Class.new do
-          module Local
+          local = Module.new do
             def received
               @received ||= []
             end
@@ -102,26 +104,26 @@ module RSpec::Rails
               {}
             end
           end
-          include Local
+          include local
           include ViewExampleGroup::ExampleMethods
         end.new
       end
 
       context "given no input" do
         it "sends render(:template => (described file)) to the view" do
-          view_spec.stub(:_default_file_to_render) { "widgets/new" }
+          allow(view_spec).to receive(:_default_file_to_render) { "widgets/new" }
           view_spec.render
-          view_spec.received.first.should == [{:template => "widgets/new"},{}, nil]
+          expect(view_spec.received.first).to eq([{:template => "widgets/new"},{}, nil])
         end
 
         it "converts the filename components into render options" do
-          view_spec.stub(:_default_file_to_render) { "widgets/new.en.html.erb" }
+          allow(view_spec).to receive(:_default_file_to_render) { "widgets/new.en.html.erb" }
           view_spec.render
 
           if ::Rails::VERSION::STRING >= '3.2'
-            view_spec.received.first.should == [{:template => "widgets/new", :locales=>['en'], :formats=>['html'], :handlers=>['erb']}, {}, nil]
+            expect(view_spec.received.first).to eq([{:template => "widgets/new", :locales=>['en'], :formats=>[:html], :handlers=>['erb']}, {}, nil])
           else
-            view_spec.received.first.should == [{:template => "widgets/new.en.html.erb"}, {}, nil]
+            expect(view_spec.received.first).to eq([{:template => "widgets/new.en.html.erb"}, {}, nil])
           end
         end
       end
@@ -129,14 +131,14 @@ module RSpec::Rails
       context "given a string" do
         it "sends string as the first arg to render" do
           view_spec.render('arbitrary/path')
-          view_spec.received.first.should == ["arbitrary/path", {}, nil]
+          expect(view_spec.received.first).to eq(["arbitrary/path", {}, nil])
         end
       end
 
       context "given a hash" do
         it "sends the hash as the first arg to render" do
           view_spec.render(:foo => 'bar')
-          view_spec.received.first.should == [{:foo => "bar"}, {}, nil]
+          expect(view_spec.received.first).to eq([{:foo => "bar"}, {}, nil])
         end
       end
     end
@@ -152,7 +154,7 @@ module RSpec::Rails
       end
 
       it 'delegates to the controller' do
-        view_spec.controller.should_receive(:params).and_return({})
+        expect(view_spec.controller).to receive(:params).and_return({})
         view_spec.params[:foo] = 1
       end
     end
@@ -165,19 +167,19 @@ module RSpec::Rails
       end
       context "with a common _default_file_to_render" do
         it "it returns the directory" do
-          view_spec.stub(:_default_file_to_render).
+          allow(view_spec).to receive(:_default_file_to_render).
             and_return("things/new.html.erb")
-          view_spec.__send__(:_controller_path).
-            should == "things"
+          expect(view_spec.__send__(:_controller_path)).
+            to eq("things")
         end
       end
 
       context "with a nested _default_file_to_render" do
         it "it returns the directory path" do
-          view_spec.stub(:_default_file_to_render).
+          allow(view_spec).to receive(:_default_file_to_render).
             and_return("admin/things/new.html.erb")
-          view_spec.__send__(:_controller_path).
-            should == "admin/things"
+          expect(view_spec.__send__(:_controller_path)).
+            to eq("admin/things")
         end
       end
     end
@@ -191,8 +193,8 @@ module RSpec::Rails
 
       it "delegates to _view" do
         view = double("view")
-        view_spec.stub(:_view) { view }
-        view_spec.view.should == view
+        allow(view_spec).to receive(:_view) { view }
+        expect(view_spec.view).to eq(view)
       end
 
       it 'is accessible to hooks' do
@@ -219,15 +221,15 @@ module RSpec::Rails
         end.new
       end
 
-      before { RSpec.stub(:deprecate) }
+      before { allow(RSpec).to receive(:deprecate) }
 
       it "is deprecated" do
-        RSpec.should_receive(:deprecate)
+        expect(RSpec).to receive(:deprecate)
         view_spec.template
       end
 
       it "delegates to #view" do
-        view_spec.should_receive(:view)
+        expect(view_spec).to receive(:view)
         view_spec.template
       end
     end
