@@ -13,7 +13,7 @@ describe "redirect_to" do
 
       it "passes" do
         expect do
-          response.should redirect_to("destination")
+          expect(response).to redirect_to("destination")
         end.to_not raise_exception
       end
     end
@@ -25,7 +25,7 @@ describe "redirect_to" do
 
       it "uses failure message from assert_redirected_to" do
         expect do
-          response.should redirect_to("destination")
+          expect(response).to redirect_to("destination")
         end.to raise_exception("this message")
       end
     end
@@ -37,7 +37,7 @@ describe "redirect_to" do
 
       it "raises that exception" do
         expect do
-          response.should redirect_to("destination")
+          expect(response).to redirect_to("destination")
         end.to raise_exception("oops")
       end
     end
@@ -51,7 +51,7 @@ describe "redirect_to" do
 
       it "passes" do
         expect do
-          response.should_not redirect_to("destination")
+          expect(response).not_to redirect_to("destination")
         end.to_not raise_exception
       end
     end
@@ -61,7 +61,7 @@ describe "redirect_to" do
 
       it "fails with custom failure message" do
         expect do
-          response.should_not redirect_to("destination")
+          expect(response).not_to redirect_to("destination")
         end.to raise_exception(/expected not to redirect to \"destination\", but did/)
       end
     end
@@ -73,7 +73,7 @@ describe "redirect_to" do
 
       it "raises that exception" do
         expect do
-          response.should_not redirect_to("destination")
+          expect(response).not_to redirect_to("destination")
         end.to raise_exception("oops")
       end
     end
