@@ -1,11 +1,17 @@
 require 'rails/all'
 
+class << RSpec
+  attr_writer :configuration
+end
+
 module RSpecRails
   class Application < ::Rails::Application
     self.config.secret_key_base = 'ASecretString' if config.respond_to? :secret_key_base
   end
 end
+I18n.enforce_available_locales = true if I18n.respond_to?(:enforce_available_locales)
 
+require 'rspec/support/spec'
 require 'rspec/rails'
 require 'ammeter/init'
 
@@ -18,15 +24,16 @@ class RSpec::Core::ExampleGroup
 end
 
 RSpec.configure do |config|
-  config.treat_symbols_as_metadata_keys_with_true_values = true
   config.filter_run :focus
   config.run_all_when_everything_filtered = true
+  config.order = :random
+
+  real_world = nil
   config.before(:each) do
-    @real_world = RSpec.world
+    real_world = RSpec.world
     RSpec.instance_variable_set(:@world, RSpec::Core::World.new)
   end
   config.after(:each) do
-    RSpec.instance_variable_set(:@world, @real_world)
+    RSpec.instance_variable_set(:@world, real_world)
   end
-  config.order = :random
 end
